==> redhat-fuse-7.10.0-sources.zip: camel-2.23.2.fuse-7_10_0-00020-redhat-00001/components/camel-ejb/src/test/java/org/apache/camel/component/ejb/GreaterTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ejb;
import java.util.Properties;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * @version 
 */
public class GreaterTest extends Assert {

    private InitialContext initialContext;

    @Before
    public void setUp() throws Exception {
        Properties properties = new Properties();
        properties.setProperty(Context.INITIAL_CONTEXT_FACTORY, "org.apache.openejb.client.LocalInitialContextFactory");

        initialContext = new InitialContext(properties);
    }

    @Test
    public void testGreaterViaLocalInterface() throws Exception {
        Object object = initialContext.lookup("GreaterImplLocal");

        assertNotNull(object);
        assertTrue(object instanceof GreaterLocal);
        GreaterLocal greater = (GreaterLocal) object;

        assertEquals("Hello World", greater.hello("World"));
    }

}

==> redhat-fuse-7.13.0-sources.zip: camel-2.23.2.fuse-7_13_0-00013-redhat-00001/components/camel-ejb/src/test/java/org/apache/camel/component/ejb/GreaterTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ejb;
import java.util.Properties;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.apache.openejb.config.DeploymentFilterable;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * @version 
 */
public class GreaterTest extends Assert {

    private InitialContext initialContext;

    @Before
    public void setUp() throws Exception {
        Properties properties = new Properties();
        properties.setProperty(Context.INITIAL_CONTEXT_FACTORY, "org.apache.openejb.client.LocalInitialContextFactory");
        properties.setProperty(DeploymentFilterable.CLASSPATH_EXCLUDE, ".*jakarta.xml.bind-api.*|.*jackson-core.*|.*jaxb-impl.*|.*log4j-api.*|.*jackson-databind.*|.*jakarta\\.activation.*|.*jackson-annotations.*");

        initialContext = new InitialContext(properties);
    }

    @Test
    public void testGreaterViaLocalInterface() throws Exception {
        Object object = initialContext.lookup("GreaterImplLocal");

        assertNotNull(object);
        assertTrue(object instanceof GreaterLocal);
        GreaterLocal greater = (GreaterLocal) object;

        assertEquals("Hello World", greater.hello("World"));
    }

}
